/**
 * Copyright (c) 2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * Inspired by https://github.com/dgasmith/gau2grid.
 *
 * @author David Sehnal <david.sehnal@gmail.com>
 */
import { WebGLContext } from '../../mol-gl/webgl/context';
import { Box3D } from '../../mol-math/geometry';
import { Vec3 } from '../../mol-math/linear-algebra';
import { Grid } from '../../mol-model/volume';
import { Task } from '../../mol-task';
import { SphericalBasisOrder } from './orbitals';
export interface CubeGridInfo {
    dimensions: Vec3;
    box: Box3D;
    size: Vec3;
    npoints: number;
    delta: Vec3;
}
export interface CubeGrid {
    grid: Grid;
    isovalues?: {
        negative?: number;
        positive?: number;
    };
}
export interface Basis {
    atoms: {
        center: Vec3;
        shells: SphericalElectronShell[];
    }[];
}
export interface SphericalElectronShell {
    exponents: number[];
    angularMomentum: number[];
    coefficients: number[][];
}
export interface SphericalCollocationParams {
    basis: Basis;
    /**
     * for each electron shell compute a cutoff radius as
     *
     *    const cutoffRadius = Math.sqrt(-Math.log(cutoffThreshold) / arrayMin(exponents));
     *
     */
    cutoffThreshold: number;
    sphericalOrder: SphericalBasisOrder;
    boxExpand: number;
    gridSpacing: number | [atomCountThreshold: number, spacing: number][];
    alphaOrbitals: number[];
    doNotComputeIsovalues?: boolean;
}
export declare function createSphericalCollocationGrid(params: SphericalCollocationParams, webgl?: WebGLContext): Task<CubeGrid>;
export declare function computeIsocontourValues(input: Float32Array, cumulativeThreshold: number): {
    negative: number | undefined;
    positive: number | undefined;
};
