"use strict";
/**
 * Copyright (c) 2018-2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRenderable = exports.createRenderObject = exports.getNextMaterialId = void 0;
var id_factory_1 = require("../mol-util/id-factory");
var direct_volume_1 = require("./renderable/direct-volume");
var mesh_1 = require("./renderable/mesh");
var points_1 = require("./renderable/points");
var lines_1 = require("./renderable/lines");
var spheres_1 = require("./renderable/spheres");
var text_1 = require("./renderable/text");
var texture_mesh_1 = require("./renderable/texture-mesh");
var image_1 = require("./renderable/image");
var cylinders_1 = require("./renderable/cylinders");
var getNextId = id_factory_1.idFactory(0, 0x7FFFFFFF);
exports.getNextMaterialId = id_factory_1.idFactory(0, 0x7FFFFFFF);
//
function createRenderObject(type, values, state, materialId) {
    return { id: getNextId(), type: type, values: values, state: state, materialId: materialId };
}
exports.createRenderObject = createRenderObject;
function createRenderable(ctx, o) {
    switch (o.type) {
        case 'mesh': return mesh_1.MeshRenderable(ctx, o.id, o.values, o.state, o.materialId);
        case 'points': return points_1.PointsRenderable(ctx, o.id, o.values, o.state, o.materialId);
        case 'spheres': return spheres_1.SpheresRenderable(ctx, o.id, o.values, o.state, o.materialId);
        case 'cylinders': return cylinders_1.CylindersRenderable(ctx, o.id, o.values, o.state, o.materialId);
        case 'text': return text_1.TextRenderable(ctx, o.id, o.values, o.state, o.materialId);
        case 'lines': return lines_1.LinesRenderable(ctx, o.id, o.values, o.state, o.materialId);
        case 'direct-volume': return direct_volume_1.DirectVolumeRenderable(ctx, o.id, o.values, o.state, o.materialId);
        case 'image': return image_1.ImageRenderable(ctx, o.id, o.values, o.state, o.materialId);
        case 'texture-mesh': return texture_mesh_1.TextureMeshRenderable(ctx, o.id, o.values, o.state, o.materialId);
    }
    throw new Error('unsupported type');
}
exports.createRenderable = createRenderable;
//# sourceMappingURL=render-object.js.map