"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var parser_1 = require("../sdf/parser");
var SdfString = "\n  Mrv1718007121815122D          \n\n  5  4  0  0  0  0            999 V2000\n    0.0000    0.8250    0.0000 O   0  5  0  0  0  0  0  0  0  0  0  0\n   -0.8250    0.0000    0.0000 O   0  0  0  0  0  0  0  0  0  0  0  0\n    0.0000   -0.8250    0.0000 O   0  5  0  0  0  0  0  0  0  0  0  0\n    0.0000    0.0000    0.0000 P   0  0  0  0  0  0  0  0  0  0  0  0\n    0.8250    0.0000    0.0000 O   0  5  0  0  0  0  0  0  0  0  0  0\n  4  1  1  0  0  0  0\n  4  2  2  0  0  0  0\n  4  3  1  0  0  0  0\n  4  5  1  0  0  0  0\nM  CHG  3   1  -1   3  -1   5  -1\nM  END\n> <DATABASE_ID>\nDB14523\n\n> <DATABASE_NAME>\ndrugbank\n\n> <SMILES>\n[O-]P([O-])([O-])=O\n\n> <INCHI_IDENTIFIER>\nInChI=1S/H3O4P/c1-5(2,3)4/h(H3,1,2,3,4)/p-3\n\n> <INCHI_KEY>\nNBIIXXVUZAFLBC-UHFFFAOYSA-K\n\n> <FORMULA>\nO4P\n\n> <MOLECULAR_WEIGHT>\n94.9714\n\n> <EXACT_MASS>\n94.95342\n\n> <JCHEM_ACCEPTOR_COUNT>\n4\n\n> <JCHEM_ATOM_COUNT>\n5\n\n> <JCHEM_AVERAGE_POLARIZABILITY>\n4.932162910070488\n\n> <JCHEM_BIOAVAILABILITY>\n1\n\n> <JCHEM_DONOR_COUNT>\n0\n\n> <JCHEM_FORMAL_CHARGE>\n-3\n\n> <JCHEM_GHOSE_FILTER>\n0\n\n> <JCHEM_IUPAC>\nphosphate\n\n> <JCHEM_LOGP>\n-1.0201038226666665\n\n> <JCHEM_MDDR_LIKE_RULE>\n0\n\n> <JCHEM_NUMBER_OF_RINGS>\n0\n\n> <JCHEM_PHYSIOLOGICAL_CHARGE>\n-2\n\n> <JCHEM_PKA>\n6.951626889535468\n\n> <JCHEM_PKA_STRONGEST_ACIDIC>\n1.7961261340181292\n\n> <JCHEM_POLAR_SURFACE_AREA>\n86.25\n\n> <JCHEM_REFRACTIVITY>\n11.2868\n\n> <JCHEM_ROTATABLE_BOND_COUNT>\n0\n\n> <JCHEM_RULE_OF_FIVE>\n1\n\n> <JCHEM_TRADITIONAL_IUPAC>\nphosphate\n\n> <JCHEM_VEBER_RULE>\n0\n\n> <DRUGBANK_ID>\nDB14523\n\n> <DRUG_GROUPS>\nexperimental\n\n> <GENERIC_NAME>\nPhosphate ion\n\n> <SYNONYMS>\nOrthophosphate; Phosphate\n\n$$$$";
describe('sdf reader', function () {
    it('basic', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var parsed, compound, molFile, dataItems, atoms, bonds;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, parser_1.parseSdf(SdfString).run()];
                case 1:
                    parsed = _a.sent();
                    if (parsed.isError) {
                        throw new Error(parsed.message);
                    }
                    compound = parsed.result.compounds[0];
                    molFile = compound.molFile, dataItems = compound.dataItems;
                    atoms = molFile.atoms, bonds = molFile.bonds;
                    // number of structures
                    expect(atoms.count).toBe(5);
                    expect(bonds.count).toBe(4);
                    expect(atoms.x.value(0)).toBeCloseTo(0, 0.001);
                    expect(atoms.y.value(0)).toBeCloseTo(0.8250, 0.0001);
                    expect(atoms.z.value(0)).toBeCloseTo(0, 0.0001);
                    expect(atoms.type_symbol.value(0)).toBe('O');
                    expect(bonds.atomIdxA.value(3)).toBe(4);
                    expect(bonds.atomIdxB.value(3)).toBe(5);
                    expect(bonds.order.value(3)).toBe(1);
                    expect(dataItems.dataHeader.value(0)).toBe('DATABASE_ID');
                    expect(dataItems.data.value(0)).toBe('DB14523');
                    expect(dataItems.dataHeader.value(1)).toBe('DATABASE_NAME');
                    expect(dataItems.data.value(1)).toBe('drugbank');
                    expect(dataItems.dataHeader.value(31)).toBe('SYNONYMS');
                    expect(dataItems.data.value(31)).toBe('Orthophosphate; Phosphate');
                    return [2 /*return*/];
            }
        });
    }); });
});
//# sourceMappingURL=sdf.spec.js.map