/**
 * Copyright (c) 2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
import { mmCIF_Schema } from '../../../mol-io/reader/cif/schema/mmcif';
import { Table } from '../../../mol-data/db';
import { mmCIF_chemComp_schema } from '../../../mol-io/reader/cif/schema/mmcif-extras';
export declare type Entry = Table<mmCIF_Schema['entry']>;
export declare type Struct = Table<mmCIF_Schema['struct']>;
export declare type StructAsym = Table<mmCIF_Schema['struct_asym']>;
export declare type IhmModelList = Table<mmCIF_Schema['ihm_model_list']>;
export declare type IhmModelGroup = Table<mmCIF_Schema['ihm_model_group']>;
export declare type IhmModelGroupLink = Table<mmCIF_Schema['ihm_model_group_link']>;
export declare type Entity = Table<mmCIF_Schema['entity']>;
export declare type EntityPoly = Table<mmCIF_Schema['entity_poly']>;
export declare type EntityPolySeq = Table<mmCIF_Schema['entity_poly_seq']>;
export declare type EntityBranch = Table<mmCIF_Schema['pdbx_entity_branch']>;
export declare type ChemComp = Table<mmCIF_chemComp_schema>;
export declare type ChemCompIdentifier = Table<mmCIF_Schema['pdbx_chem_comp_identifier']>;
export declare type AtomSite = Table<mmCIF_Schema['atom_site']>;
export declare type IhmSphereObjSite = Table<mmCIF_Schema['ihm_sphere_obj_site']>;
export declare type IhmGaussianObjSite = Table<mmCIF_Schema['ihm_gaussian_obj_site']>;
export declare type UnobsOrZeroOccResidues = Table<mmCIF_Schema['pdbx_unobs_or_zero_occ_residues']>;
export declare type Molecule = Table<mmCIF_Schema['pdbx_molecule']>;
export declare const BasicSchema: {
    entry: {
        id: import("../../../mol-data/db/column").default.Schema.Str;
    };
    struct: {
        entry_id: import("../../../mol-data/db/column").default.Schema.Str;
        title: import("../../../mol-data/db/column").default.Schema.Str;
        pdbx_descriptor: import("../../../mol-data/db/column").default.Schema.Str;
    };
    struct_asym: {
        details: import("../../../mol-data/db/column").default.Schema.Str;
        entity_id: import("../../../mol-data/db/column").default.Schema.Str;
        id: import("../../../mol-data/db/column").default.Schema.Str;
        pdbx_modified: import("../../../mol-data/db/column").default.Schema.Str;
        pdbx_blank_PDB_chainid_flag: import("../../../mol-data/db/column").default.Schema.Aliased<"N" | "Y">;
    };
    ihm_model_list: {
        model_id: import("../../../mol-data/db/column").default.Schema.Int;
        model_name: import("../../../mol-data/db/column").default.Schema.Str;
        assembly_id: import("../../../mol-data/db/column").default.Schema.Int;
        protocol_id: import("../../../mol-data/db/column").default.Schema.Int;
        representation_id: import("../../../mol-data/db/column").default.Schema.Int;
    };
    ihm_model_group: {
        id: import("../../../mol-data/db/column").default.Schema.Int;
        name: import("../../../mol-data/db/column").default.Schema.Str;
        details: import("../../../mol-data/db/column").default.Schema.Str;
    };
    ihm_model_group_link: {
        model_id: import("../../../mol-data/db/column").default.Schema.Int;
        group_id: import("../../../mol-data/db/column").default.Schema.Int;
    };
    entity: {
        details: import("../../../mol-data/db/column").default.Schema.Str;
        formula_weight: import("../../../mol-data/db/column").default.Schema.Float;
        id: import("../../../mol-data/db/column").default.Schema.Str;
        src_method: import("../../../mol-data/db/column").default.Schema.Aliased<"nat" | "man" | "syn">;
        type: import("../../../mol-data/db/column").default.Schema.Aliased<"non-polymer" | "polymer" | "macrolide" | "water" | "branched">;
        pdbx_description: import("../../../mol-data/db/column").default.Schema.List<string>;
        pdbx_number_of_molecules: import("../../../mol-data/db/column").default.Schema.Int;
        pdbx_mutation: import("../../../mol-data/db/column").default.Schema.Str;
        pdbx_fragment: import("../../../mol-data/db/column").default.Schema.Str;
        pdbx_ec: import("../../../mol-data/db/column").default.Schema.List<string>;
    };
    entity_poly: {
        entity_id: import("../../../mol-data/db/column").default.Schema.Str;
        nstd_linkage: import("../../../mol-data/db/column").default.Schema.Aliased<"no" | "n" | "yes" | "y">;
        nstd_monomer: import("../../../mol-data/db/column").default.Schema.Aliased<"no" | "n" | "yes" | "y">;
        type: import("../../../mol-data/db/column").default.Schema.Aliased<"other" | "polypeptide(D)" | "polypeptide(L)" | "polydeoxyribonucleotide" | "polyribonucleotide" | "polydeoxyribonucleotide/polyribonucleotide hybrid" | "cyclic-pseudo-peptide" | "peptide nucleic acid">;
        pdbx_strand_id: import("../../../mol-data/db/column").default.Schema.List<string>;
        pdbx_seq_one_letter_code: import("../../../mol-data/db/column").default.Schema.Str;
        pdbx_seq_one_letter_code_can: import("../../../mol-data/db/column").default.Schema.Str;
        pdbx_target_identifier: import("../../../mol-data/db/column").default.Schema.Str;
    };
    entity_poly_seq: {
        entity_id: import("../../../mol-data/db/column").default.Schema.Str;
        hetero: import("../../../mol-data/db/column").default.Schema.Aliased<"no" | "n" | "yes" | "y">;
        mon_id: import("../../../mol-data/db/column").default.Schema.Str;
        num: import("../../../mol-data/db/column").default.Schema.Int;
    };
    pdbx_entity_branch: {
        entity_id: import("../../../mol-data/db/column").default.Schema.Str;
        type: import("../../../mol-data/db/column").default.Schema.Aliased<"oligosaccharide">;
    };
    chem_comp: {
        type: import("../../../mol-data/db/column").default.Schema.Aliased<"D-peptide linking" | "L-peptide linking" | "D-peptide NH3 amino terminus" | "L-peptide NH3 amino terminus" | "D-peptide COOH carboxy terminus" | "L-peptide COOH carboxy terminus" | "DNA linking" | "RNA linking" | "L-RNA linking" | "L-DNA linking" | "DNA OH 5 prime terminus" | "RNA OH 5 prime terminus" | "DNA OH 3 prime terminus" | "RNA OH 3 prime terminus" | "D-saccharide, beta linking" | "D-saccharide, alpha linking" | "L-saccharide, beta linking" | "L-saccharide, alpha linking" | "L-saccharide" | "D-saccharide" | "saccharide" | "non-polymer" | "peptide linking" | "peptide-like" | "L-gamma-peptide, C-delta linking" | "D-gamma-peptide, C-delta linking" | "L-beta-peptide, C-gamma linking" | "D-beta-peptide, C-gamma linking" | "other" | "Ion" | "Lipid">;
        formula: import("../../../mol-data/db/column").default.Schema.Str;
        formula_weight: import("../../../mol-data/db/column").default.Schema.Float;
        id: import("../../../mol-data/db/column").default.Schema.Str;
        mon_nstd_flag: import("../../../mol-data/db/column").default.Schema.Aliased<"no" | "n" | "yes" | "y">;
        name: import("../../../mol-data/db/column").default.Schema.Str;
        pdbx_synonyms: import("../../../mol-data/db/column").default.Schema.List<string>;
    };
    pdbx_chem_comp_identifier: {
        comp_id: import("../../../mol-data/db/column").default.Schema.Str;
        identifier: import("../../../mol-data/db/column").default.Schema.Str;
        type: import("../../../mol-data/db/column").default.Schema.Aliased<"COMMON NAME" | "SYSTEMATIC NAME" | "CAS REGISTRY NUMBER" | "PUBCHEM Identifier" | "MDL Identifier" | "SYNONYM" | "CONDENSED IUPAC CARB SYMBOL" | "IUPAC CARB SYMBOL" | "SNFG CARB SYMBOL" | "CONDENSED IUPAC CARBOHYDRATE SYMBOL" | "IUPAC CARBOHYDRATE SYMBOL" | "SNFG CARBOHYDRATE SYMBOL">;
        program: import("../../../mol-data/db/column").default.Schema.Str;
        program_version: import("../../../mol-data/db/column").default.Schema.Str;
    };
    atom_site: {
        auth_asym_id: import("../../../mol-data/db/column").default.Schema.Str;
        auth_atom_id: import("../../../mol-data/db/column").default.Schema.Str;
        auth_comp_id: import("../../../mol-data/db/column").default.Schema.Str;
        auth_seq_id: import("../../../mol-data/db/column").default.Schema.Int;
        B_iso_or_equiv: import("../../../mol-data/db/column").default.Schema.Float;
        Cartn_x: import("../../../mol-data/db/column").default.Schema.Coordinate;
        Cartn_y: import("../../../mol-data/db/column").default.Schema.Coordinate;
        Cartn_z: import("../../../mol-data/db/column").default.Schema.Coordinate;
        group_PDB: import("../../../mol-data/db/column").default.Schema.Aliased<"ATOM" | "HETATM">;
        id: import("../../../mol-data/db/column").default.Schema.Int;
        label_alt_id: import("../../../mol-data/db/column").default.Schema.Str;
        label_asym_id: import("../../../mol-data/db/column").default.Schema.Str;
        label_atom_id: import("../../../mol-data/db/column").default.Schema.Str;
        label_comp_id: import("../../../mol-data/db/column").default.Schema.Str;
        label_entity_id: import("../../../mol-data/db/column").default.Schema.Str;
        label_seq_id: import("../../../mol-data/db/column").default.Schema.Int;
        occupancy: import("../../../mol-data/db/column").default.Schema.Float;
        type_symbol: import("../../../mol-data/db/column").default.Schema.Str;
        pdbx_PDB_ins_code: import("../../../mol-data/db/column").default.Schema.Str;
        pdbx_PDB_model_num: import("../../../mol-data/db/column").default.Schema.Int;
        pdbx_formal_charge: import("../../../mol-data/db/column").default.Schema.Int;
        ihm_model_id: import("../../../mol-data/db/column").default.Schema.Int;
    };
    ihm_sphere_obj_site: {
        id: import("../../../mol-data/db/column").default.Schema.Int;
        entity_id: import("../../../mol-data/db/column").default.Schema.Str;
        seq_id_begin: import("../../../mol-data/db/column").default.Schema.Int;
        seq_id_end: import("../../../mol-data/db/column").default.Schema.Int;
        asym_id: import("../../../mol-data/db/column").default.Schema.Str;
        Cartn_x: import("../../../mol-data/db/column").default.Schema.Float;
        Cartn_y: import("../../../mol-data/db/column").default.Schema.Float;
        Cartn_z: import("../../../mol-data/db/column").default.Schema.Float;
        object_radius: import("../../../mol-data/db/column").default.Schema.Float;
        rmsf: import("../../../mol-data/db/column").default.Schema.Float;
        model_id: import("../../../mol-data/db/column").default.Schema.Int;
    };
    ihm_gaussian_obj_site: {
        id: import("../../../mol-data/db/column").default.Schema.Int;
        entity_id: import("../../../mol-data/db/column").default.Schema.Str;
        seq_id_begin: import("../../../mol-data/db/column").default.Schema.Int;
        seq_id_end: import("../../../mol-data/db/column").default.Schema.Int;
        asym_id: import("../../../mol-data/db/column").default.Schema.Str;
        mean_Cartn_x: import("../../../mol-data/db/column").default.Schema.Float;
        mean_Cartn_y: import("../../../mol-data/db/column").default.Schema.Float;
        mean_Cartn_z: import("../../../mol-data/db/column").default.Schema.Float;
        weight: import("../../../mol-data/db/column").default.Schema.Float;
        covariance_matrix: import("../../../mol-data/db/column").default.Schema.Tensor;
        model_id: import("../../../mol-data/db/column").default.Schema.Int;
    };
    pdbx_unobs_or_zero_occ_residues: {
        id: import("../../../mol-data/db/column").default.Schema.Int;
        polymer_flag: import("../../../mol-data/db/column").default.Schema.Aliased<"N" | "Y">;
        occupancy_flag: import("../../../mol-data/db/column").default.Schema.Aliased<"1" | "0">;
        PDB_model_num: import("../../../mol-data/db/column").default.Schema.Int;
        auth_asym_id: import("../../../mol-data/db/column").default.Schema.Str;
        auth_comp_id: import("../../../mol-data/db/column").default.Schema.Str;
        auth_seq_id: import("../../../mol-data/db/column").default.Schema.Str;
        PDB_ins_code: import("../../../mol-data/db/column").default.Schema.Str;
        label_asym_id: import("../../../mol-data/db/column").default.Schema.Str;
        label_comp_id: import("../../../mol-data/db/column").default.Schema.Str;
        label_seq_id: import("../../../mol-data/db/column").default.Schema.Int;
    };
    pdbx_molecule: {
        prd_id: import("../../../mol-data/db/column").default.Schema.Str;
        instance_id: import("../../../mol-data/db/column").default.Schema.Int;
        asym_id: import("../../../mol-data/db/column").default.Schema.Str;
    };
};
export interface BasicData {
    entry: Entry;
    struct: Struct;
    struct_asym: StructAsym;
    ihm_model_list: IhmModelList;
    ihm_model_group: IhmModelGroup;
    ihm_model_group_link: IhmModelGroupLink;
    entity: Entity;
    entity_poly: EntityPoly;
    entity_poly_seq: EntityPolySeq;
    pdbx_entity_branch: EntityBranch;
    chem_comp: ChemComp;
    pdbx_chem_comp_identifier: ChemCompIdentifier;
    atom_site: AtomSite;
    ihm_sphere_obj_site: IhmSphereObjSite;
    ihm_gaussian_obj_site: IhmGaussianObjSite;
    pdbx_unobs_or_zero_occ_residues: UnobsOrZeroOccResidues;
    pdbx_molecule: Molecule;
}
export declare function createBasic(data: Partial<BasicData>): BasicData;
