"use strict";
/**
 * Copyright (c) 2019-2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Coordinates = exports.Time = void 0;
var mol_util_1 = require("../../../mol-util");
var db_1 = require("../../../mol-data/db");
function Time(value, unit) {
    return { value: value, unit: unit };
}
exports.Time = Time;
var Coordinates;
(function (Coordinates) {
    function create(frames, deltaTime, timeOffset) {
        var hasCell = !!frames[0].cell;
        var hasVelocities = !!frames[0].velocities;
        var hasForces = !!frames[0].forces;
        return {
            id: mol_util_1.UUID.create22(),
            frames: frames,
            hasCell: hasCell,
            hasVelocities: hasVelocities,
            hasForces: hasForces,
            deltaTime: deltaTime,
            timeOffset: timeOffset
        };
    }
    Coordinates.create = create;
    function getAtomicConformation(frame, atomId) {
        return {
            id: mol_util_1.UUID.create22(),
            atomId: atomId,
            occupancy: db_1.Column.ofConst(1, frame.elementCount, db_1.Column.Schema.int),
            B_iso_or_equiv: db_1.Column.ofConst(0, frame.elementCount, db_1.Column.Schema.float),
            xyzDefined: true,
            x: frame.x,
            y: frame.y,
            z: frame.z,
        };
    }
    Coordinates.getAtomicConformation = getAtomicConformation;
    function reorderCoords(xs, index) {
        var ret = new Float32Array(xs.length);
        for (var i = 0, _i = xs.length; i < _i; i++) {
            ret[i] = xs[index[i]];
        }
        return ret;
    }
    function getAtomicConformationReordered(frame, atomId, srcIndex) {
        return {
            id: mol_util_1.UUID.create22(),
            atomId: atomId,
            occupancy: db_1.Column.ofConst(1, frame.elementCount, db_1.Column.Schema.int),
            B_iso_or_equiv: db_1.Column.ofConst(0, frame.elementCount, db_1.Column.Schema.float),
            xyzDefined: true,
            x: reorderCoords(frame.x, srcIndex),
            y: reorderCoords(frame.y, srcIndex),
            z: reorderCoords(frame.z, srcIndex)
        };
    }
    Coordinates.getAtomicConformationReordered = getAtomicConformationReordered;
})(Coordinates || (Coordinates = {}));
exports.Coordinates = Coordinates;
//# sourceMappingURL=coordinates.js.map