"use strict";
/**
 * Copyright (c) 2019 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author David Sehnal <david.sehnal@gmail.com>
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LeftPanelControls = void 0;
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var canvas3d_1 = require("../mol-canvas3d/canvas3d");
var commands_1 = require("../mol-plugin/commands");
var mol_state_1 = require("../mol-state");
var base_1 = require("./base");
var common_1 = require("./controls/common");
var parameters_1 = require("./controls/parameters");
var actions_1 = require("./state/actions");
var snapshots_1 = require("./state/snapshots");
var tree_1 = require("./state/tree");
var help_1 = require("./viewport/help");
var icons_1 = require("./controls/icons");
var LeftPanelControls = /** @class */ (function (_super) {
    tslib_1.__extends(LeftPanelControls, _super);
    function LeftPanelControls() {
        var _a;
        var _this = _super.apply(this, arguments) || this;
        _this.state = { tab: _this.plugin.behaviors.layout.leftPanelTabName.value };
        _this.set = function (tab) {
            if (_this.state.tab === tab) {
                _this.setState({ tab: 'none' }, function () { return _this.plugin.behaviors.layout.leftPanelTabName.next('none'); });
                commands_1.PluginCommands.Layout.Update(_this.plugin, { state: { regionState: tslib_1.__assign(tslib_1.__assign({}, _this.plugin.layout.state.regionState), { left: 'collapsed' }) } });
                return;
            }
            _this.setState({ tab: tab }, function () { return _this.plugin.behaviors.layout.leftPanelTabName.next(tab); });
            if (_this.plugin.layout.state.regionState.left !== 'full') {
                commands_1.PluginCommands.Layout.Update(_this.plugin, { state: { regionState: tslib_1.__assign(tslib_1.__assign({}, _this.plugin.layout.state.regionState), { left: 'full' }) } });
            }
        };
        _this.tabs = {
            'none': React.createElement(React.Fragment, null),
            'root': React.createElement(React.Fragment, null,
                React.createElement(common_1.SectionHeader, { icon: icons_1.HomeOutlinedSvg, title: 'Home' }),
                React.createElement(actions_1.StateObjectActions, { state: _this.plugin.state.data, nodeRef: mol_state_1.StateTransform.RootRef, hideHeader: true, initiallyCollapsed: true, alwaysExpandFirst: true }),
                ((_a = _this.plugin.spec.components) === null || _a === void 0 ? void 0 : _a.remoteState) !== 'none' && React.createElement(snapshots_1.RemoteStateSnapshots, { listOnly: true })),
            'data': React.createElement(React.Fragment, null,
                React.createElement(common_1.SectionHeader, { icon: icons_1.AccountTreeOutlinedSvg, title: React.createElement(React.Fragment, null,
                        React.createElement(RemoveAllButton, null),
                        " State Tree") }),
                React.createElement(tree_1.StateTree, { state: _this.plugin.state.data })),
            'states': React.createElement(snapshots_1.StateSnapshots, null),
            'settings': React.createElement(React.Fragment, null,
                React.createElement(common_1.SectionHeader, { icon: icons_1.TuneSvg, title: 'Plugin Settings' }),
                React.createElement(FullSettings, null)),
            'help': React.createElement(React.Fragment, null,
                React.createElement(common_1.SectionHeader, { icon: icons_1.HelpOutlineSvg, title: 'Help' }),
                React.createElement(help_1.HelpContent, null))
        };
        return _this;
    }
    LeftPanelControls.prototype.componentDidMount = function () {
        var _this = this;
        this.subscribe(this.plugin.behaviors.layout.leftPanelTabName, function (tab) {
            if (_this.state.tab !== tab)
                _this.setState({ tab: tab });
            if (tab === 'none' && _this.plugin.layout.state.regionState.left !== 'collapsed') {
                commands_1.PluginCommands.Layout.Update(_this.plugin, { state: { regionState: tslib_1.__assign(tslib_1.__assign({}, _this.plugin.layout.state.regionState), { left: 'collapsed' }) } });
            }
        });
        this.subscribe(this.plugin.state.data.events.changed, function (_a) {
            var state = _a.state;
            if (_this.state.tab !== 'data')
                return;
            if (state.cells.size === 1)
                _this.set('root');
        });
    };
    LeftPanelControls.prototype.render = function () {
        var _this = this;
        var tab = this.state.tab;
        return React.createElement("div", { className: 'msp-left-panel-controls' },
            React.createElement("div", { className: 'msp-left-panel-controls-buttons' },
                React.createElement(common_1.IconButton, { svg: icons_1.HomeOutlinedSvg, toggleState: tab === 'root', transparent: true, onClick: function () { return _this.set('root'); }, title: 'Home' }),
                React.createElement(DataIcon, { set: this.set }),
                React.createElement(common_1.IconButton, { svg: icons_1.SaveOutlinedSvg, toggleState: tab === 'states', transparent: true, onClick: function () { return _this.set('states'); }, title: 'Plugin State' }),
                React.createElement(common_1.IconButton, { svg: icons_1.HelpOutlineSvg, toggleState: tab === 'help', transparent: true, onClick: function () { return _this.set('help'); }, title: 'Help' }),
                React.createElement("div", { className: 'msp-left-panel-controls-buttons-bottom' },
                    React.createElement(common_1.IconButton, { svg: icons_1.TuneSvg, toggleState: tab === 'settings', transparent: true, onClick: function () { return _this.set('settings'); }, title: 'Settings' }))),
            React.createElement("div", { className: 'msp-scrollable-container' }, this.tabs[tab]));
    };
    return LeftPanelControls;
}(base_1.PluginUIComponent));
exports.LeftPanelControls = LeftPanelControls;
var DataIcon = /** @class */ (function (_super) {
    tslib_1.__extends(DataIcon, _super);
    function DataIcon() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = { changed: false };
        return _this;
    }
    Object.defineProperty(DataIcon.prototype, "tab", {
        get: function () {
            return this.plugin.behaviors.layout.leftPanelTabName.value;
        },
        enumerable: false,
        configurable: true
    });
    DataIcon.prototype.componentDidMount = function () {
        var _this = this;
        this.subscribe(this.plugin.behaviors.layout.leftPanelTabName, function (tab) {
            if (_this.tab === 'data')
                _this.setState({ changed: false });
            else
                _this.forceUpdate();
        });
        this.subscribe(this.plugin.state.data.events.changed, function (state) {
            if (_this.tab !== 'data')
                _this.setState({ changed: true });
        });
    };
    DataIcon.prototype.render = function () {
        var _this = this;
        return React.createElement(common_1.IconButton, { svg: icons_1.AccountTreeOutlinedSvg, toggleState: this.tab === 'data', transparent: true, onClick: function () { return _this.props.set('data'); }, title: 'State Tree', style: { position: 'relative' }, extraContent: this.state.changed ? React.createElement("div", { className: 'msp-left-panel-controls-button-data-dirty' }) : void 0 });
    };
    return DataIcon;
}(base_1.PluginUIComponent));
var FullSettings = /** @class */ (function (_super) {
    tslib_1.__extends(FullSettings, _super);
    function FullSettings() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.setSettings = function (p) {
            var _a;
            commands_1.PluginCommands.Canvas3D.SetSettings(_this.plugin, { settings: (_a = {}, _a[p.name] = p.value, _a) });
        };
        return _this;
    }
    FullSettings.prototype.componentDidMount = function () {
        var _this = this;
        this.subscribe(this.plugin.events.canvas3d.settingsUpdated, function () { return _this.forceUpdate(); });
        this.subscribe(this.plugin.layout.events.updated, function () { return _this.forceUpdate(); });
        this.subscribe(this.plugin.canvas3d.camera.stateChanged, function (state) {
            if (state.radiusMax !== undefined || state.radius !== undefined) {
                _this.forceUpdate();
            }
        });
    };
    FullSettings.prototype.render = function () {
        return React.createElement(React.Fragment, null,
            this.plugin.canvas3d && React.createElement(React.Fragment, null,
                React.createElement(common_1.SectionHeader, { title: 'Viewport' }),
                React.createElement(parameters_1.ParameterControls, { params: canvas3d_1.Canvas3DParams, values: this.plugin.canvas3d.props, onChange: this.setSettings })),
            React.createElement(common_1.SectionHeader, { title: 'Behavior' }),
            React.createElement(tree_1.StateTree, { state: this.plugin.state.behaviors }));
    };
    return FullSettings;
}(base_1.PluginUIComponent));
var RemoveAllButton = /** @class */ (function (_super) {
    tslib_1.__extends(RemoveAllButton, _super);
    function RemoveAllButton() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.remove = function (e) {
            e.preventDefault();
            commands_1.PluginCommands.State.RemoveObject(_this.plugin, { state: _this.plugin.state.data, ref: mol_state_1.StateTransform.RootRef });
        };
        return _this;
    }
    RemoveAllButton.prototype.componentDidMount = function () {
        var _this = this;
        this.subscribe(this.plugin.state.events.cell.created, function (e) {
            if (e.cell.transform.parent === mol_state_1.StateTransform.RootRef)
                _this.forceUpdate();
        });
        this.subscribe(this.plugin.state.events.cell.removed, function (e) {
            if (e.parent === mol_state_1.StateTransform.RootRef)
                _this.forceUpdate();
        });
    };
    RemoveAllButton.prototype.render = function () {
        var count = this.plugin.state.data.tree.children.get(mol_state_1.StateTransform.RootRef).size;
        if (count === 0)
            return null;
        return React.createElement(common_1.IconButton, { svg: icons_1.DeleteOutlinedSvg, onClick: this.remove, title: 'Remove All', style: { display: 'inline-block' }, small: true, className: 'msp-no-hover-outline', transparent: true });
    };
    return RemoveAllButton;
}(base_1.PluginUIComponent));
//# sourceMappingURL=left-panel.js.map