/**
 * Copyright (c) 2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
import { ParamDefinition as PD } from '../../mol-util/param-definition';
import { Image } from '../../mol-geo/geometry/image/image';
import { ThemeRegistryContext, Theme } from '../../mol-theme/theme';
import { Volume } from '../../mol-model/volume';
import { VolumeVisual, VolumeRepresentation, VolumeRepresentationProvider } from './representation';
import { RepresentationContext, RepresentationParamsGetter } from '../representation';
import { VisualContext } from '../visual';
export declare function createImage(ctx: VisualContext, volume: Volume, theme: Theme, props: PD.Values<SliceParams>, image?: Image): Promise<Image>;
export declare const SliceParams: {
    quality: {
        isEssential: boolean;
        type: "select";
        options: readonly (readonly ["custom" | "auto" | "highest" | "higher" | "high" | "medium" | "low" | "lower" | "lowest", string] | readonly ["custom" | "auto" | "highest" | "higher" | "high" | "medium" | "low" | "lower" | "lowest", string, string | undefined])[];
        cycle?: boolean | undefined;
        isOptional?: boolean | undefined;
        defaultValue: "custom" | "auto" | "highest" | "higher" | "high" | "medium" | "low" | "lower" | "lowest";
        label?: string | undefined;
        description?: string | undefined;
        legend?: import("../../mol-util/legend").TableLegend | import("../../mol-util/legend").ScaleLegend | undefined;
        fieldLabels?: {
            [name: string]: string;
        } | undefined;
        isHidden?: boolean | undefined;
        shortLabel?: boolean | undefined;
        twoColumns?: boolean | undefined;
        category?: string | undefined;
        hideIf?: ((currentGroup: any) => boolean) | undefined;
        help?: ((value: any) => {
            description?: string | undefined;
            legend?: import("../../mol-util/legend").TableLegend | import("../../mol-util/legend").ScaleLegend | undefined;
        }) | undefined;
    };
    dimension: PD.Mapped<PD.NamedParams<number, "y"> | PD.NamedParams<number, "x"> | PD.NamedParams<number, "z">>;
    isoValue: PD.Conditioned<Volume.IsoValue, PD.Base<Volume.IsoValue>, {
        absolute: PD.Converted<Readonly<{
            kind: "absolute";
            absoluteValue: number;
        }>, number>;
        relative: PD.Converted<Readonly<{
            kind: "relative";
            relativeValue: number;
        }>, number>;
    }>;
    interpolation: PD.Select<"nearest" | "bspline" | "catmulrom" | "mitchell">;
    alpha: PD.Numeric;
};
export declare type SliceParams = typeof SliceParams;
export declare function getSliceParams(ctx: ThemeRegistryContext, volume: Volume): {
    quality: {
        isEssential: boolean;
        type: "select";
        options: readonly (readonly ["custom" | "auto" | "highest" | "higher" | "high" | "medium" | "low" | "lower" | "lowest", string] | readonly ["custom" | "auto" | "highest" | "higher" | "high" | "medium" | "low" | "lower" | "lowest", string, string | undefined])[];
        cycle?: boolean | undefined;
        isOptional?: boolean | undefined;
        defaultValue: "custom" | "auto" | "highest" | "higher" | "high" | "medium" | "low" | "lower" | "lowest";
        label?: string | undefined;
        description?: string | undefined;
        legend?: import("../../mol-util/legend").TableLegend | import("../../mol-util/legend").ScaleLegend | undefined;
        fieldLabels?: {
            [name: string]: string;
        } | undefined;
        isHidden?: boolean | undefined;
        shortLabel?: boolean | undefined;
        twoColumns?: boolean | undefined;
        category?: string | undefined;
        hideIf?: ((currentGroup: any) => boolean) | undefined;
        help?: ((value: any) => {
            description?: string | undefined;
            legend?: import("../../mol-util/legend").TableLegend | import("../../mol-util/legend").ScaleLegend | undefined;
        }) | undefined;
    };
    dimension: PD.Mapped<PD.NamedParams<number, "y"> | PD.NamedParams<number, "x"> | PD.NamedParams<number, "z">>;
    isoValue: PD.Conditioned<Volume.IsoValue, PD.Base<Volume.IsoValue>, {
        absolute: PD.Converted<Readonly<{
            kind: "absolute";
            absoluteValue: number;
        }>, number>;
        relative: PD.Converted<Readonly<{
            kind: "relative";
            relativeValue: number;
        }>, number>;
    }>;
    interpolation: PD.Select<"nearest" | "bspline" | "catmulrom" | "mitchell">;
    alpha: PD.Numeric;
};
export declare function SliceVisual(materialId: number): VolumeVisual<SliceParams>;
export declare function SliceRepresentation(ctx: RepresentationContext, getParams: RepresentationParamsGetter<Volume, SliceParams>): VolumeRepresentation<SliceParams>;
export declare const SliceRepresentationProvider: VolumeRepresentationProvider<{
    quality: {
        isEssential: boolean;
        type: "select";
        options: readonly (readonly ["custom" | "auto" | "highest" | "higher" | "high" | "medium" | "low" | "lower" | "lowest", string] | readonly ["custom" | "auto" | "highest" | "higher" | "high" | "medium" | "low" | "lower" | "lowest", string, string | undefined])[];
        cycle?: boolean | undefined;
        isOptional?: boolean | undefined;
        defaultValue: "custom" | "auto" | "highest" | "higher" | "high" | "medium" | "low" | "lower" | "lowest";
        label?: string | undefined;
        description?: string | undefined;
        legend?: import("../../mol-util/legend").TableLegend | import("../../mol-util/legend").ScaleLegend | undefined;
        fieldLabels?: {
            [name: string]: string;
        } | undefined;
        isHidden?: boolean | undefined;
        shortLabel?: boolean | undefined;
        twoColumns?: boolean | undefined;
        category?: string | undefined;
        hideIf?: ((currentGroup: any) => boolean) | undefined;
        help?: ((value: any) => {
            description?: string | undefined;
            legend?: import("../../mol-util/legend").TableLegend | import("../../mol-util/legend").ScaleLegend | undefined;
        }) | undefined;
    };
    dimension: PD.Mapped<PD.NamedParams<number, "y"> | PD.NamedParams<number, "x"> | PD.NamedParams<number, "z">>;
    isoValue: PD.Conditioned<Volume.IsoValue, PD.Base<Volume.IsoValue>, {
        absolute: PD.Converted<Readonly<{
            kind: "absolute";
            absoluteValue: number;
        }>, number>;
        relative: PD.Converted<Readonly<{
            kind: "relative";
            relativeValue: number;
        }>, number>;
    }>;
    interpolation: PD.Select<"nearest" | "bspline" | "catmulrom" | "mitchell">;
    alpha: PD.Numeric;
}, "slice">;
