"use strict";
/**
 * Copyright (c) 2018-2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorThemeProvider = exports.ColorTheme = void 0;
var color_1 = require("../mol-util/color");
var carbohydrate_symbol_1 = require("./color/carbohydrate-symbol");
var uniform_1 = require("./color/uniform");
var mol_util_1 = require("../mol-util");
var theme_1 = require("./theme");
var chain_id_1 = require("./color/chain-id");
var element_index_1 = require("./color/element-index");
var element_symbol_1 = require("./color/element-symbol");
var molecule_type_1 = require("./color/molecule-type");
var polymer_id_1 = require("./color/polymer-id");
var polymer_index_1 = require("./color/polymer-index");
var residue_name_1 = require("./color/residue-name");
var secondary_structure_1 = require("./color/secondary-structure");
var sequence_id_1 = require("./color/sequence-id");
var shape_group_1 = require("./color/shape-group");
var unit_index_1 = require("./color/unit-index");
var uncertainty_1 = require("./color/uncertainty");
var entity_source_1 = require("./color/entity-source");
var illustrative_1 = require("./color/illustrative");
var hydrophobicity_1 = require("./color/hydrophobicity");
var model_index_1 = require("./color/model-index");
var occupancy_1 = require("./color/occupancy");
var operator_name_1 = require("./color/operator-name");
var operator_hkl_1 = require("./color/operator-hkl");
var partial_charge_1 = require("./color/partial-charge");
var ColorTheme;
(function (ColorTheme) {
    ColorTheme.EmptyFactory = function () { return ColorTheme.Empty; };
    var EmptyColor = color_1.Color(0xCCCCCC);
    ColorTheme.Empty = {
        factory: ColorTheme.EmptyFactory,
        granularity: 'uniform',
        color: function () { return EmptyColor; },
        props: {}
    };
    function areEqual(themeA, themeB) {
        return themeA.contextHash === themeB.contextHash && themeA.factory === themeB.factory && mol_util_1.deepEqual(themeA.props, themeB.props);
    }
    ColorTheme.areEqual = areEqual;
    ColorTheme.EmptyProvider = { name: '', label: '', category: '', factory: ColorTheme.EmptyFactory, getParams: function () { return ({}); }, defaultValues: {}, isApplicable: function () { return true; } };
    function createRegistry() {
        return new theme_1.ThemeRegistry(ColorTheme.BuiltIn, ColorTheme.EmptyProvider);
    }
    ColorTheme.createRegistry = createRegistry;
    ColorTheme.BuiltIn = {
        'carbohydrate-symbol': carbohydrate_symbol_1.CarbohydrateSymbolColorThemeProvider,
        'chain-id': chain_id_1.ChainIdColorThemeProvider,
        'element-index': element_index_1.ElementIndexColorThemeProvider,
        'element-symbol': element_symbol_1.ElementSymbolColorThemeProvider,
        'entity-source': entity_source_1.EntitySourceColorThemeProvider,
        'hydrophobicity': hydrophobicity_1.HydrophobicityColorThemeProvider,
        'illustrative': illustrative_1.IllustrativeColorThemeProvider,
        'model-index': model_index_1.ModelIndexColorThemeProvider,
        'molecule-type': molecule_type_1.MoleculeTypeColorThemeProvider,
        'occupancy': occupancy_1.OccupancyColorThemeProvider,
        'operator-hkl': operator_hkl_1.OperatorHklColorThemeProvider,
        'operator-name': operator_name_1.OperatorNameColorThemeProvider,
        'partial-charge': partial_charge_1.PartialChargeColorThemeProvider,
        'polymer-id': polymer_id_1.PolymerIdColorThemeProvider,
        'polymer-index': polymer_index_1.PolymerIndexColorThemeProvider,
        'residue-name': residue_name_1.ResidueNameColorThemeProvider,
        'secondary-structure': secondary_structure_1.SecondaryStructureColorThemeProvider,
        'sequence-id': sequence_id_1.SequenceIdColorThemeProvider,
        'shape-group': shape_group_1.ShapeGroupColorThemeProvider,
        'uncertainty': uncertainty_1.UncertaintyColorThemeProvider,
        'unit-index': unit_index_1.UnitIndexColorThemeProvider,
        'uniform': uniform_1.UniformColorThemeProvider,
    };
})(ColorTheme || (ColorTheme = {}));
exports.ColorTheme = ColorTheme;
function ColorThemeProvider(p) { return p; }
exports.ColorThemeProvider = ColorThemeProvider;
//# sourceMappingURL=color.js.map