"use strict";
/**
 * Copyright (c) 2019-2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IllustrativeColorThemeProvider = exports.IllustrativeColorTheme = exports.getIllustrativeColorThemeParams = exports.IllustrativeColorThemeParams = void 0;
var tslib_1 = require("tslib");
var color_1 = require("../../mol-util/color");
var structure_1 = require("../../mol-model/structure");
var param_definition_1 = require("../../mol-util/param-definition");
var chain_id_1 = require("./chain-id");
var DefaultIllustrativeColor = color_1.Color(0xEEEEEE);
var Description = "Assigns an illustrative color that gives every chain a unique color with lighter carbons (inspired by David Goodsell's Molecule of the Month style).";
exports.IllustrativeColorThemeParams = tslib_1.__assign({}, chain_id_1.ChainIdColorThemeParams);
function getIllustrativeColorThemeParams(ctx) {
    return exports.IllustrativeColorThemeParams; // TODO return copy
}
exports.getIllustrativeColorThemeParams = getIllustrativeColorThemeParams;
function IllustrativeColorTheme(ctx, props) {
    var _a = chain_id_1.ChainIdColorTheme(ctx, props), chainIdColor = _a.color, legend = _a.legend;
    function illustrativeColor(location, typeSymbol) {
        var baseColor = chainIdColor(location, false);
        return typeSymbol === 'C' ? color_1.Color.lighten(baseColor, 0.8) : baseColor;
    }
    function color(location) {
        if (structure_1.StructureElement.Location.is(location) && structure_1.Unit.isAtomic(location.unit)) {
            var typeSymbol = location.unit.model.atomicHierarchy.atoms.type_symbol.value(location.element);
            return illustrativeColor(location, typeSymbol);
        }
        else if (structure_1.Bond.isLocation(location) && structure_1.Unit.isAtomic(location.aUnit)) {
            var elementIndex = location.aUnit.elements[location.aIndex];
            var typeSymbol = location.aUnit.model.atomicHierarchy.atoms.type_symbol.value(elementIndex);
            return illustrativeColor(location, typeSymbol);
        }
        return DefaultIllustrativeColor;
    }
    return {
        factory: IllustrativeColorTheme,
        granularity: 'group',
        color: color,
        props: props,
        description: Description,
        legend: legend
    };
}
exports.IllustrativeColorTheme = IllustrativeColorTheme;
exports.IllustrativeColorThemeProvider = {
    name: 'illustrative',
    label: 'Illustrative',
    category: "Miscellaneous" /* Misc */,
    factory: IllustrativeColorTheme,
    getParams: getIllustrativeColorThemeParams,
    defaultValues: param_definition_1.ParamDefinition.getDefaultValues(exports.IllustrativeColorThemeParams),
    isApplicable: function (ctx) { return !!ctx.structure; }
};
//# sourceMappingURL=illustrative.js.map