"use strict";
/**
 * Copyright (c) 2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorCosine = exports.PositionColorThemeProvider = exports.PositionColorTheme = exports.getPositionColorThemeParams = exports.PositionColorThemeParams = void 0;
var color_1 = require("../../mol-util/color");
var param_definition_1 = require("../../mol-util/param-definition");
var location_iterator_1 = require("../../mol-geo/util/location-iterator");
var linear_algebra_1 = require("../../mol-math/linear-algebra");
var DefaultColor = color_1.Color(0xCCCCCC);
var Description = 'Gives geometry vertex colors based on positions.';
exports.PositionColorThemeParams = {};
function getPositionColorThemeParams(ctx) {
    return exports.PositionColorThemeParams; // TODO return copy
}
exports.getPositionColorThemeParams = getPositionColorThemeParams;
function PositionColorTheme(ctx, props) {
    var p = linear_algebra_1.Vec3();
    return {
        factory: PositionColorTheme,
        granularity: 'vertexInstance',
        color: function (location) {
            if (location_iterator_1.isPositionLocation(location)) {
                linear_algebra_1.Vec3.scale(p, location.position, 1 / 50);
                return ColorCosine.palette6(p);
            }
            return DefaultColor;
        },
        props: props,
        description: Description,
    };
}
exports.PositionColorTheme = PositionColorTheme;
exports.PositionColorThemeProvider = {
    name: 'position',
    label: 'Position',
    category: "Miscellaneous" /* Misc */,
    factory: PositionColorTheme,
    getParams: getPositionColorThemeParams,
    defaultValues: param_definition_1.ParamDefinition.getDefaultValues(exports.PositionColorThemeParams),
    isApplicable: function (ctx) { return true; }
};
//
// ported from https://iquilezles.org/www/articles/palettes/palettes.htm
var ColorCosine;
(function (ColorCosine) {
    var tmp = linear_algebra_1.Vec3();
    function palette(t, a, b, c, d) {
        // a + b * cos(6.28318 * (c * t + d))
        linear_algebra_1.Vec3.mul(tmp, c, t);
        linear_algebra_1.Vec3.add(tmp, tmp, d);
        linear_algebra_1.Vec3.scale(tmp, tmp, 6.28318);
        tmp[0] = Math.cos(tmp[0]);
        tmp[1] = Math.cos(tmp[1]);
        tmp[2] = Math.cos(tmp[2]);
        linear_algebra_1.Vec3.mul(tmp, b, tmp);
        linear_algebra_1.Vec3.add(tmp, a, tmp);
        return color_1.Color.fromNormalizedArray(tmp, 0);
    }
    ColorCosine.palette = palette;
    var a6 = linear_algebra_1.Vec3.create(0.5, 0.5, 0.5);
    var b6 = linear_algebra_1.Vec3.create(0.5, 0.5, 0.5);
    var c6 = linear_algebra_1.Vec3.create(2.0, 1.0, 0.0);
    var d6 = linear_algebra_1.Vec3.create(0.50, 0.20, 0.25);
    function palette6(t) {
        return palette(t, a6, b6, c6, d6);
    }
    ColorCosine.palette6 = palette6;
})(ColorCosine = exports.ColorCosine || (exports.ColorCosine = {}));
//# sourceMappingURL=position.js.map