"use strict";
/**
 * Copyright (c) 2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.VolumeColorThemeProvider = exports.VolumeColorTheme = exports.getVolumeColorThemeParams = exports.VolumeColorThemeParams = void 0;
var color_1 = require("../../mol-util/color");
var param_definition_1 = require("../../mol-util/param-definition");
var volume_1 = require("../../mol-model/volume");
var location_iterator_1 = require("../../mol-geo/util/location-iterator");
var color_2 = require("../../mol-util/color/color");
var linear_algebra_1 = require("../../mol-math/linear-algebra");
var DefaultColor = color_1.Color(0xCCCCCC);
var Description = 'Gives geometry vertex colors based on a volume.';
exports.VolumeColorThemeParams = {
    volume: param_definition_1.ParamDefinition.Value(volume_1.Volume),
};
function getVolumeColorThemeParams(ctx) {
    return exports.VolumeColorThemeParams; // TODO return copy
}
exports.getVolumeColorThemeParams = getVolumeColorThemeParams;
function VolumeColorTheme(ctx, props) {
    var p = linear_algebra_1.Vec3();
    return {
        factory: VolumeColorTheme,
        granularity: 'vertexInstance',
        color: function (location) {
            if (location_iterator_1.isPositionLocation(location)) {
                linear_algebra_1.Vec3.scale(p, location.position, 1 / 50);
                return color_2.ColorCosine.palette6(p);
            }
            return DefaultColor;
        },
        props: props,
        description: Description,
    };
}
exports.VolumeColorTheme = VolumeColorTheme;
exports.VolumeColorThemeProvider = {
    name: 'volume',
    label: 'Volume',
    category: "Miscellaneous" /* Misc */,
    factory: VolumeColorTheme,
    getParams: getVolumeColorThemeParams,
    defaultValues: param_definition_1.ParamDefinition.getDefaultValues(exports.VolumeColorThemeParams),
    isApplicable: function (ctx) { return true; }
};
//# sourceMappingURL=volume.js.map