"use strict";
/**
 * Copyright (c) 2017 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author David Sehnal <david.sehnal@gmail.com>
 */
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var string_builder_1 = tslib_1.__importDefault(require("../string-builder"));
describe('string-builder', function () {
    function check(name, bb, expected) {
        var sb = string_builder_1.default.create();
        bb(sb);
        it(name, function () { return expect(string_builder_1.default.getString(sb)).toEqual(expected); });
    }
    check('write', function (sb) { return string_builder_1.default.write(sb, '123'); }, '123');
    check('whitespace', function (sb) { return string_builder_1.default.whitespace(sb, 3); }, '   ');
    check('writePadLeft', function (sb) { return string_builder_1.default.writePadLeft(sb, '1', 3); }, '  1');
    check('writePadRight', function (sb) { return string_builder_1.default.writePadRight(sb, '1', 3); }, '1  ');
    check('writeIntegerPadLeft', function (sb) { return string_builder_1.default.writeIntegerPadLeft(sb, -125, 5); }, ' -125');
    check('writeIntegerPadRight', function (sb) { return string_builder_1.default.writeIntegerPadRight(sb, -125, 5); }, '-125 ');
    check('writeFloat', function (sb) { return string_builder_1.default.writeFloat(sb, 1.123, 100); }, '1.12');
    check('writeFloatPadLeft', function (sb) { return string_builder_1.default.writeFloatPadLeft(sb, 1.123, 100, 6); }, '  1.12');
    check('writeFloatPadRight', function (sb) { return string_builder_1.default.writeFloatPadRight(sb, -1.123, 100, 6); }, '-1.12 ');
    it('chunks', function () {
        var sb = string_builder_1.default.create(2);
        string_builder_1.default.write(sb, '1');
        string_builder_1.default.write(sb, '2');
        string_builder_1.default.write(sb, '3');
        expect(string_builder_1.default.getChunks(sb)).toEqual(['12', '3']);
        expect(string_builder_1.default.getString(sb)).toEqual('123');
    });
});
//# sourceMappingURL=string-builder.spec.js.map