/**
 * Copyright (c) 2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author David Sehnal <david.sehnal@gmail.com>
 */
import { __awaiter, __extends, __generator } from "tslib";
import { PluginStateObject, PluginStateTransform } from '../../mol-plugin-state/objects';
import { createSphericalCollocationGrid } from '../../extensions/alpha-orbitals/cubes';
import { ParamDefinition as PD } from '../../mol-util/param-definition';
import { Task } from '../../mol-task';
import { CustomProperties } from '../../mol-model/custom-property';
var BasisAndOrbitals = /** @class */ (function (_super) {
    __extends(BasisAndOrbitals, _super);
    function BasisAndOrbitals() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return BasisAndOrbitals;
}(PluginStateObject.Create({ name: 'Basis', typeClass: 'Object' })));
export { BasisAndOrbitals };
export var StaticBasisAndOrbitals = PluginStateTransform.BuiltIn({
    name: 'static-basis-and-orbitals',
    display: 'Basis and Orbitals',
    from: PluginStateObject.Root,
    to: BasisAndOrbitals,
    params: {
        label: PD.Text('Orbital Data', { isHidden: true }),
        basis: PD.Value(void 0, { isHidden: true }),
        order: PD.Text('gaussian', { isHidden: true }),
        orbitals: PD.Value([], { isHidden: true })
    },
})({
    apply: function (_a) {
        var params = _a.params;
        return new BasisAndOrbitals({ basis: params.basis, order: params.order, orbitals: params.orbitals }, { label: params.label });
    }
});
export var CreateOrbitalVolume = PluginStateTransform.BuiltIn({
    name: 'create-orbital-volume',
    display: 'Orbital Volume',
    from: BasisAndOrbitals,
    to: PluginStateObject.Volume.Data,
    params: function (a) {
        if (!a) {
            return { index: PD.Numeric(0) };
        }
        return {
            index: PD.Select(0, a.data.orbitals.map(function (o, i) { return [i, "[" + (i + 1) + "] " + o.energy.toFixed(4)]; }))
        };
    }
})({
    apply: function (_a) {
        var _this = this;
        var a = _a.a, params = _a.params;
        return Task.create('Orbital Volume', function (ctx) { return __awaiter(_this, void 0, void 0, function () {
            var data, volume;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, createSphericalCollocationGrid({
                            basis: a.data.basis,
                            cutoffThreshold: 0.0075,
                            alphaOrbitals: a.data.orbitals[params.index].alpha,
                            sphericalOrder: a.data.order,
                            boxExpand: 4.5,
                            gridSpacing: [
                                [55, 0.6],
                                [40, 0.5],
                                [25, 0.4],
                                [0, 0.33],
                            ],
                        }).runInContext(ctx)];
                    case 1:
                        data = _a.sent();
                        volume = {
                            grid: data.grid,
                            sourceData: { name: 'custom grid', kind: 'custom', data: data },
                            customProperties: new CustomProperties(),
                            _propertyData: Object.create(null),
                        };
                        return [2 /*return*/, new PluginStateObject.Volume.Data(volume, { label: 'Orbital Volume' })];
                }
            });
        }); });
    }
});
//# sourceMappingURL=transforms.js.map