/**
 * Copyright (c) 2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Sebastian Bittrich <sebastian.bittrich@rcsb.org>
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
import { Structure } from '../../mol-model/structure';
import { Task, RuntimeContext } from '../../mol-task';
import { Vec3 } from '../../mol-math/linear-algebra';
import { ParamDefinition as PD } from '../../mol-util/param-definition';
import { MembraneOrientation } from './prop';
export declare const ANVILParams: {
    numberOfSpherePoints: PD.Numeric;
    stepSize: PD.Numeric;
    minThickness: PD.Numeric;
    maxThickness: PD.Numeric;
    asaCutoff: PD.Numeric;
};
export declare type ANVILParams = typeof ANVILParams;
export declare type ANVILProps = PD.Values<ANVILParams>;
/**
 * Implements:
 * Membrane positioning for high- and low-resolution protein structures through a binary classification approach
 * Guillaume Postic, Yassine Ghouzam, Vincent Guiraud, and Jean-Christophe Gelly
 * Protein Engineering, Design & Selection, 2015, 1–5
 * doi: 10.1093/protein/gzv063
 */
export declare function computeANVIL(structure: Structure, props: ANVILProps): Task<MembraneOrientation>;
export declare function calculate(runtime: RuntimeContext, structure: Structure, params: ANVILProps): Promise<MembraneOrientation>;
export declare function isInMembranePlane(testPoint: Vec3, normalVector: Vec3, planePoint1: Vec3, planePoint2: Vec3): boolean;
export declare function isHydrophobic(label_comp_id: string): boolean;
