/**
 * Copyright (c) 2019 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
import { __awaiter, __generator } from "tslib";
import { ReaderResult as Result } from '../result';
import { Task } from '../../../mol-task';
import { parseCsv } from '../csv/parser';
import { Column } from '../../../mol-data/db';
import { toTable } from '../cif/schema';
var Schema = Column.Schema;
export var Schema3DG = {
    /** Chromosome name */
    chromosome: Schema.str,
    /** Base position */
    position: Schema.int,
    /** X coordinate */
    x: Schema.float,
    /** Y coordinate */
    y: Schema.float,
    /** Z coordinate */
    z: Schema.float,
};
var FieldNames = ['chromosome', 'position', 'x', 'y', 'z'];
function categoryFromTable(name, table) {
    return {
        name: name,
        rowCount: table.rowCount,
        fieldNames: FieldNames,
        getField: function (name) {
            return table.getColumn(FieldNames.indexOf(name).toString());
        }
    };
}
export function parse3DG(data) {
    var _this = this;
    return Task.create('Parse 3DG', function (ctx) { return __awaiter(_this, void 0, void 0, function () {
        var opts, csvFile, category, table;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    opts = { quote: '', comment: '#', delimiter: '\t', noColumnNames: true };
                    return [4 /*yield*/, parseCsv(data, opts).runInContext(ctx)];
                case 1:
                    csvFile = _a.sent();
                    if (csvFile.isError)
                        return [2 /*return*/, Result.error(csvFile.message, csvFile.line)];
                    category = categoryFromTable('3dg', csvFile.result.table);
                    table = toTable(Schema3DG, category);
                    return [2 /*return*/, Result.success({ table: table })];
            }
        });
    }); });
}
//# sourceMappingURL=parser.js.map