/**
 * Copyright (c) 2018-2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author David Sehnal <david.sehnal@gmail.com>
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
import { StateTransformer } from '../../mol-state';
import { ParamDefinition as PD } from '../../mol-util/param-definition';
import { PluginStateObject as SO } from '../objects';
import { Asset } from '../../mol-util/assets';
export { Download };
export { DownloadBlob };
export { RawData };
export { ReadFile };
export { ParseBlob };
export { ParseCif };
export { ParseCube };
export { ParsePsf };
export { ParsePly };
export { ParseCcp4 };
export { ParseDsn6 };
export { ParseDx };
export { ImportString };
export { ImportJson };
export { ParseJson };
declare type Download = typeof Download;
declare const Download: StateTransformer<SO.Root, SO.Data.String | SO.Data.Binary, PD.Normalize<{
    url: string | Asset.Url;
    label: string | undefined;
    isBinary: boolean | undefined;
}>>;
declare type DownloadBlob = typeof DownloadBlob;
declare const DownloadBlob: StateTransformer<SO.Root, SO.Data.Blob, PD.Normalize<{
    sources: PD.Normalize<{
        id: any;
        url: any;
        isBinary: any;
        canFail: any;
    }>[];
    maxConcurrency: number | undefined;
}>>;
declare type RawData = typeof RawData;
declare const RawData: StateTransformer<SO.Root, SO.Data.String | SO.Data.Binary, PD.Normalize<{
    data: string | number[] | Uint8Array | ArrayBuffer;
    label: string | undefined;
}>>;
declare type ReadFile = typeof ReadFile;
declare const ReadFile: StateTransformer<SO.Root, SO.Data.String | SO.Data.Binary, PD.Normalize<{
    file: Asset.File | null;
    label: string | undefined;
    isBinary: boolean | undefined;
}>>;
declare type ParseBlob = typeof ParseBlob;
declare const ParseBlob: StateTransformer<SO.Data.Blob, SO.Format.Blob, PD.Normalize<{
    formats: PD.Normalize<{
        id: any;
        format: any;
    }>[];
}>>;
declare type ParseCif = typeof ParseCif;
declare const ParseCif: StateTransformer<SO.Data.String | SO.Data.Binary, SO.Format.Cif, PD.Normalize<{}>>;
declare type ParseCube = typeof ParseCube;
declare const ParseCube: StateTransformer<SO.Data.String, SO.Format.Cube, PD.Normalize<{}>>;
declare type ParsePsf = typeof ParsePsf;
declare const ParsePsf: StateTransformer<SO.Data.String, SO.Format.Psf, PD.Normalize<{}>>;
declare type ParsePly = typeof ParsePly;
declare const ParsePly: StateTransformer<SO.Data.String, SO.Format.Ply, PD.Normalize<{}>>;
declare type ParseCcp4 = typeof ParseCcp4;
declare const ParseCcp4: StateTransformer<SO.Data.Binary, SO.Format.Ccp4, PD.Normalize<{}>>;
declare type ParseDsn6 = typeof ParseDsn6;
declare const ParseDsn6: StateTransformer<SO.Data.Binary, SO.Format.Dsn6, PD.Normalize<{}>>;
declare type ParseDx = typeof ParseDx;
declare const ParseDx: StateTransformer<SO.Data.String | SO.Data.Binary, SO.Format.Dx, PD.Normalize<{}>>;
declare type ImportString = typeof ImportString;
declare const ImportString: StateTransformer<SO.Root, SO.Data.String, PD.Normalize<{
    data: string;
    label: string | undefined;
}>>;
declare type ImportJson = typeof ImportJson;
declare const ImportJson: StateTransformer<SO.Root, SO.Format.Json, PD.Normalize<{
    data: any;
    label: string | undefined;
}>>;
declare type ParseJson = typeof ParseJson;
declare const ParseJson: StateTransformer<SO.Data.String, SO.Format.Json, PD.Normalize<{}>>;
