/**
 * Copyright (c) 2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
import { Color } from '../../mol-util/color';
import { ParamDefinition as PD } from '../../mol-util/param-definition';
import { isPositionLocation } from '../../mol-geo/util/location-iterator';
import { Vec3 } from '../../mol-math/linear-algebra';
var DefaultColor = Color(0xCCCCCC);
var Description = 'Gives geometry vertex colors based on positions.';
export var PositionColorThemeParams = {};
export function getPositionColorThemeParams(ctx) {
    return PositionColorThemeParams; // TODO return copy
}
export function PositionColorTheme(ctx, props) {
    var p = Vec3();
    return {
        factory: PositionColorTheme,
        granularity: 'vertexInstance',
        color: function (location) {
            if (isPositionLocation(location)) {
                Vec3.scale(p, location.position, 1 / 50);
                return ColorCosine.palette6(p);
            }
            return DefaultColor;
        },
        props: props,
        description: Description,
    };
}
export var PositionColorThemeProvider = {
    name: 'position',
    label: 'Position',
    category: "Miscellaneous" /* Misc */,
    factory: PositionColorTheme,
    getParams: getPositionColorThemeParams,
    defaultValues: PD.getDefaultValues(PositionColorThemeParams),
    isApplicable: function (ctx) { return true; }
};
//
// ported from https://iquilezles.org/www/articles/palettes/palettes.htm
export var ColorCosine;
(function (ColorCosine) {
    var tmp = Vec3();
    function palette(t, a, b, c, d) {
        // a + b * cos(6.28318 * (c * t + d))
        Vec3.mul(tmp, c, t);
        Vec3.add(tmp, tmp, d);
        Vec3.scale(tmp, tmp, 6.28318);
        tmp[0] = Math.cos(tmp[0]);
        tmp[1] = Math.cos(tmp[1]);
        tmp[2] = Math.cos(tmp[2]);
        Vec3.mul(tmp, b, tmp);
        Vec3.add(tmp, a, tmp);
        return Color.fromNormalizedArray(tmp, 0);
    }
    ColorCosine.palette = palette;
    var a6 = Vec3.create(0.5, 0.5, 0.5);
    var b6 = Vec3.create(0.5, 0.5, 0.5);
    var c6 = Vec3.create(2.0, 1.0, 0.0);
    var d6 = Vec3.create(0.50, 0.20, 0.25);
    function palette6(t) {
        return palette(t, a6, b6, c6, d6);
    }
    ColorCosine.palette6 = palette6;
})(ColorCosine || (ColorCosine = {}));
//# sourceMappingURL=position.js.map