/**
 * Copyright (c) 2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
import { Color } from '../../mol-util/color';
import { ParamDefinition as PD } from '../../mol-util/param-definition';
import { Volume } from '../../mol-model/volume';
import { isPositionLocation } from '../../mol-geo/util/location-iterator';
import { Vec3 } from '../../mol-math/linear-algebra';
var DefaultColor = Color(0xCCCCCC);
var Description = 'Gives geometry vertex colors based on a volume.';
export var VolumeColorThemeParams = {
    volume: PD.Value(Volume),
};
export function getVolumeColorThemeParams(ctx) {
    return VolumeColorThemeParams; // TODO return copy
}
export function VolumeColorTheme(ctx, props) {
    var p = Vec3();
    return {
        factory: VolumeColorTheme,
        granularity: 'vertexInstance',
        color: function (location) {
            if (isPositionLocation(location)) {
                Vec3.scale(p, location.position, 1 / 50);
                return ColorCosine.palette6(p);
            }
            return DefaultColor;
        },
        props: props,
        description: Description,
    };
}
export var VolumeColorThemeProvider = {
    name: 'volume',
    label: 'Volume',
    category: "Miscellaneous" /* Misc */,
    factory: VolumeColorTheme,
    getParams: getVolumeColorThemeParams,
    defaultValues: PD.getDefaultValues(VolumeColorThemeParams),
    isApplicable: function (ctx) { return true; }
};
//
export function v3cos(out, a) {
    out[0] = Math.cos(a[0]);
    out[1] = Math.cos(a[1]);
    out[2] = Math.cos(a[2]);
    return out;
}
// ported from https://iquilezles.org/www/articles/palettes/palettes.htm
export var ColorCosine;
(function (ColorCosine) {
    var tmp = Vec3();
    function palette(t, a, b, c, d) {
        // a + b * cos(6.28318 * (c * t + d))
        Vec3.mul(tmp, c, t);
        Vec3.add(tmp, tmp, d);
        Vec3.scale(tmp, tmp, 6.28318);
        v3cos(tmp, tmp);
        Vec3.mul(tmp, b, tmp);
        Vec3.add(tmp, a, tmp);
        return Color.fromNormalizedArray(tmp, 0);
    }
    ColorCosine.palette = palette;
    var a1 = Vec3.create(0.5, 0.5, 0.5);
    var b1 = Vec3.create(0.5, 0.5, 0.5);
    var c1 = Vec3.create(1.0, 1.0, 1.0);
    var d1 = Vec3.create(0.00, 0.33, 0.67);
    function palette1(t) {
        return palette(t, a1, b1, c1, d1);
    }
    ColorCosine.palette1 = palette1;
    var d2 = Vec3.create(0.00, 0.10, 0.20);
    function palette2(t) {
        return palette(t, a1, b1, c1, d2);
    }
    ColorCosine.palette2 = palette2;
    var d3 = Vec3.create(0.30, 0.20, 0.20);
    function palette3(t) {
        return palette(t, a1, b1, c1, d3);
    }
    ColorCosine.palette3 = palette3;
    var d4 = Vec3.create(0.80, 0.90, 0.30);
    function palette4(t) {
        return palette(t, a1, b1, c1, d4);
    }
    ColorCosine.palette4 = palette4;
    var c5 = Vec3.create(1.0, 0.7, 0.4);
    var d5 = Vec3.create(0.00, 0.15, 0.20);
    function palette5(t) {
        return palette(t, a1, b1, c5, d5);
    }
    ColorCosine.palette5 = palette5;
    var c6 = Vec3.create(2.0, 1.0, 0.0);
    var d6 = Vec3.create(0.50, 0.20, 0.25);
    function palette6(t) {
        return palette(t, a1, b1, c6, d6);
    }
    ColorCosine.palette6 = palette6;
    var a7 = Vec3.create(0.8, 0.5, 0.4);
    var b7 = Vec3.create(0.2, 0.4, 0.2);
    var d7 = Vec3.create(0.00, 0.25, 0.25);
    function palette7(t) {
        return palette(t, a7, b7, c6, d7);
    }
    ColorCosine.palette7 = palette7;
})(ColorCosine || (ColorCosine = {}));
//# sourceMappingURL=volume.js.map